##################
PyTwitch |version|
##################

Introduction
============

PyTwitch makes it easy to integrate Twitch into your own project.

Contribute
==========

Do you want to make this even better? Don't hesitate to fork the project at `GitHub <https://github.com/dhh-hss/pytwitch>`_!


.. image:: https://travis-ci.org/dhh-hss/pytwitch.svg?branch=master
    :target: https://travis-ci.org/dhh-hss/pytwitch
    :alt: Build Status

.. image:: https://readthedocs.org/projects/pytwitch/badge/?version=latest
    :target: https://pytwitch.readthedocs.org
    :alt: Documentation

.. image:: https://img.shields.io/badge/github-source-blue.png
    :target: https://github.com/dhh-hss/pytwitch
    :alt: Github Source

.. image:: https://pypip.in/license/pytwitch/badge.png
    :target: https://github.com/dhh-hss/pytwitch/blob/master/LICENSE
    :alt: License

.. image:: https://pypip.in/status/pytwitch/badge.png
    :target: https://pypi.python.org/pypi/pytwitch
    :alt: Development Status

.. image:: https://pypip.in/py_versions/pytwitch/badge.png
    :target: https://pypi.python.org/pypi/pytwitch
    :alt: Supported Python versions

.. |version| image:: https://pypip.in/version/pytwitch/badge.png
    :target: https://pypi.python.org/pypi/pytwitch
    :alt: Latest Version
